# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/model/v1/event.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/model/v1/event.proto',
  package='v1.model',
  syntax='proto3',
  serialized_options=b'Z)github.com/FormantIO/genproto/go/v1/model',
  serialized_pb=b'\n\x1bprotos/model/v1/event.proto\x12\x08v1.model\"\x9c\x02\n\x05\x45vent\x12\x1c\n\ttimestamp\x18\x01 \x01(\x03R\ttimestamp\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x1f\n\x0bstream_name\x18\x03 \x01(\tR\nstreamName\x12\x1f\n\x0bstream_type\x18\x04 \x01(\tR\nstreamType\x12\x31\n\x14notification_enabled\x18\x05 \x01(\x08R\x13notificationEnabled\x12-\n\x04tags\x18\x06 \x03(\x0b\x32\x19.v1.model.Event.TagsEntryR\x04tags\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3'
)




_EVENT_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='v1.model.Event.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v1.model.Event.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.Event.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=326,
)

_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='v1.model.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='v1.model.Event.timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='v1.model.Event.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='message', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_name', full_name='v1.model.Event.stream_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='streamName', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_type', full_name='v1.model.Event.stream_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='streamType', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notification_enabled', full_name='v1.model.Event.notification_enabled', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='notificationEnabled', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='v1.model.Event.tags', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tags', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_EVENT_TAGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=326,
)

_EVENT_TAGSENTRY.containing_type = _EVENT
_EVENT.fields_by_name['tags'].message_type = _EVENT_TAGSENTRY
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EVENT_TAGSENTRY,
    '__module__' : 'protos.model.v1.event_pb2'
    # @@protoc_insertion_point(class_scope:v1.model.Event.TagsEntry)
    })
  ,
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Event)
  })
_sym_db.RegisterMessage(Event)
_sym_db.RegisterMessage(Event.TagsEntry)


DESCRIPTOR._options = None
_EVENT_TAGSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/model/v1/rtc.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import math_pb2 as protos_dot_model_dot_v1_dot_math__pb2
from formant.protos.model.v1 import navigation_pb2 as protos_dot_model_dot_v1_dot_navigation__pb2
from formant.protos.model.v1 import media_pb2 as protos_dot_model_dot_v1_dot_media__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/model/v1/rtc.proto',
  package='v1.model',
  syntax='proto3',
  serialized_options=b'Z)github.com/FormantIO/genproto/go/v1/model',
  serialized_pb=b'\n\x19protos/model/v1/rtc.proto\x12\x08v1.model\x1a\x1aprotos/model/v1/math.proto\x1a protos/model/v1/navigation.proto\x1a\x1bprotos/model/v1/media.proto\"\xa9\x02\n\nRTCMessage\x12\x16\n\x06stream\x18\x01 \x01(\tR\x06stream\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\x12\'\n\x05twist\x18\x03 \x01(\x0b\x32\x0f.v1.model.TwistH\x00R\x05twist\x12\x14\n\x04\x62ool\x18\x04 \x01(\x08H\x00R\x04\x62ool\x12+\n\x10\x63ompressed_image\x18\x05 \x01(\x0cH\x00R\x0f\x63ompressedImage\x12+\n\x07goal_id\x18\x06 \x01(\x0b\x32\x10.v1.model.GoalIDH\x00R\x06goalId\x12\x44\n\x10h264_video_frame\x18\x07 \x01(\x0b\x32\x18.v1.model.H264VideoFrameH\x00R\x0eh264VideoFrameB\x06\n\x04\x64\x61taB+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3'
  ,
  dependencies=[protos_dot_model_dot_v1_dot_math__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_navigation__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_media__pb2.DESCRIPTOR,])




_RTCMESSAGE = _descriptor.Descriptor(
  name='RTCMessage',
  full_name='v1.model.RTCMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream', full_name='v1.model.RTCMessage.stream', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='stream', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='v1.model.RTCMessage.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='twist', full_name='v1.model.RTCMessage.twist', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='twist', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bool', full_name='v1.model.RTCMessage.bool', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='bool', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compressed_image', full_name='v1.model.RTCMessage.compressed_image', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='compressedImage', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='goal_id', full_name='v1.model.RTCMessage.goal_id', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='goalId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='h264_video_frame', full_name='v1.model.RTCMessage.h264_video_frame', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='h264VideoFrame', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='v1.model.RTCMessage.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=131,
  serialized_end=428,
)

_RTCMESSAGE.fields_by_name['twist'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TWIST
_RTCMESSAGE.fields_by_name['goal_id'].message_type = protos_dot_model_dot_v1_dot_navigation__pb2._GOALID
_RTCMESSAGE.fields_by_name['h264_video_frame'].message_type = protos_dot_model_dot_v1_dot_media__pb2._H264VIDEOFRAME
_RTCMESSAGE.oneofs_by_name['data'].fields.append(
  _RTCMESSAGE.fields_by_name['twist'])
_RTCMESSAGE.fields_by_name['twist'].containing_oneof = _RTCMESSAGE.oneofs_by_name['data']
_RTCMESSAGE.oneofs_by_name['data'].fields.append(
  _RTCMESSAGE.fields_by_name['bool'])
_RTCMESSAGE.fields_by_name['bool'].containing_oneof = _RTCMESSAGE.oneofs_by_name['data']
_RTCMESSAGE.oneofs_by_name['data'].fields.append(
  _RTCMESSAGE.fields_by_name['compressed_image'])
_RTCMESSAGE.fields_by_name['compressed_image'].containing_oneof = _RTCMESSAGE.oneofs_by_name['data']
_RTCMESSAGE.oneofs_by_name['data'].fields.append(
  _RTCMESSAGE.fields_by_name['goal_id'])
_RTCMESSAGE.fields_by_name['goal_id'].containing_oneof = _RTCMESSAGE.oneofs_by_name['data']
_RTCMESSAGE.oneofs_by_name['data'].fields.append(
  _RTCMESSAGE.fields_by_name['h264_video_frame'])
_RTCMESSAGE.fields_by_name['h264_video_frame'].containing_oneof = _RTCMESSAGE.oneofs_by_name['data']
DESCRIPTOR.message_types_by_name['RTCMessage'] = _RTCMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RTCMessage = _reflection.GeneratedProtocolMessageType('RTCMessage', (_message.Message,), {
  'DESCRIPTOR' : _RTCMESSAGE,
  '__module__' : 'protos.model.v1.rtc_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.RTCMessage)
  })
_sym_db.RegisterMessage(RTCMessage)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
